==> nuggets-fabric-1.21.1-1.0.11.44-sources.jar: com/hollingsworth/nuggets/client/rendering/FakeRenderingWorld.java <==
package com.hollingsworth.nuggets.client.rendering;

import net.minecraft.class_1266;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1845;
import net.minecraft.class_1863;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_1959;
import net.minecraft.class_22;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_2350;
import net.minecraft.class_238;
import net.minecraft.class_2394;
import net.minecraft.class_243;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_269;
import net.minecraft.class_2784;
import net.minecraft.class_2791;
import net.minecraft.class_2802;
import net.minecraft.class_2806;
import net.minecraft.class_2874;
import net.minecraft.class_2902;
import net.minecraft.class_310;
import net.minecraft.class_3414;
import net.minecraft.class_3419;
import net.minecraft.class_3568;
import net.minecraft.class_3610;
import net.minecraft.class_3611;
import net.minecraft.class_3612;
import net.minecraft.class_4076;
import net.minecraft.class_4543;
import net.minecraft.class_5217;
import net.minecraft.class_5269;
import net.minecraft.class_5455;
import net.minecraft.class_5575;
import net.minecraft.class_5577;
import net.minecraft.class_5712;
import net.minecraft.class_5819;
import net.minecraft.class_638;
import net.minecraft.class_6754;
import net.minecraft.class_6756;
import net.minecraft.class_6880;
import net.minecraft.class_7699;
import net.minecraft.class_8921;
import net.minecraft.class_9209;
import net.minecraft.core.*;
import net.minecraft.server.MinecraftServer;
import javax.annotation.Nullable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.function.Predicate;

public class FakeRenderingWorld extends class_1937 implements class_1936 {
    public final HashMap<class_2338, class_2680> positions = new HashMap<>();
    private class_1937 realWorld;
    private class_2338 lookingAt;

    public FakeRenderingWorld(class_1937 rWorld, ArrayList<StatePos> coordinates, class_2338 lookingAt) {
        this(rWorld);
        this.lookingAt = lookingAt;
        for (StatePos statePos : coordinates) {
            this.method_8652(statePos.pos, statePos.state, 0);
        }
        for (StatePos statePos : coordinates) {
            try {
                class_2680 adjustedState = class_2248.method_9510(statePos.state, this, statePos.pos);
                this.method_8652(statePos.pos, adjustedState, 0);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public FakeRenderingWorld(class_1937 world) {
        super((class_5269) world.method_8401(), world.method_27983(), world.method_30349(), world.method_40134(),
                world::method_16107, world.field_9236, world.method_27982(), 0, 0);
        this.realWorld = world;
    }

    @Nullable
    @Override
    public class_2586 method_8321(class_2338 pos) {
        class_2680 blockState = method_8320(pos);
        if (blockState.method_31709()) {
            class_2586 blockEntity = ((class_2343) blockState.method_26204()).method_10123(pos.method_10081(lookingAt), blockState);
            if(blockEntity == null){
                return null;
            }
            blockEntity.method_31662(this.realWorld);
            return blockEntity;
        }
        return null;
    }

    @Override
    public class_2680 method_8320(class_2338 pos) {
        return positions.containsKey(pos) ? positions.get(pos) : realWorld.method_8320(pos.method_10081(lookingAt));
    }

    public class_2680 getBlockStateWithoutReal(class_2338 pos) {
        return positions.containsKey(pos) ? positions.get(pos) : class_2246.field_10124.method_9564();
    }

    @Override
    public void method_39279(class_2338 p_186461_, class_2248 p_186462_, int p_186463_) {
        //noOp
    }

    @Override
    public boolean method_8652(class_2338 p_46944_, class_2680 p_46945_, int p_46946_) {
        return this.method_30092(p_46944_, p_46945_, p_46946_, 512);
    }

    @Override
    public boolean method_30092(class_2338 pos, class_2680 state, int p_46949_, int p_46950_) {
        positions.put(pos, state);
        return true;
    }

    @Override
    public class_3610 method_8316(class_2338 pos) {
        return class_3612.field_15906.method_15785();
    }

    @Override
    public int method_31605() {
        return realWorld.method_31605();
    }

    @Override
    public class_5455 method_30349() {
        return null;
    }

    @Override
    public class_1845 method_59547() {
        return null;
    }

    @Override
    public class_7699 method_45162() {
        return null;
    }

    @org.jetbrains.annotations.Nullable
    @Override
    public class_2791 method_8402(int pX, int pZ, class_2806 pChunkStatus, boolean pRequireChunk) {
        return null;
    }

    @Override
    public int method_8624(class_2902.class_2903 p_46827_, int p_46828_, int p_46829_) {
        return 0;
    }

    @Override
    public int method_8594() {
        return 0;
    }

    @Override
    public class_4543 method_22385() {
        return realWorld.method_22385();
    }

    @Override
    protected class_5577<class_1297> method_31592() {
        return null;
    }

    @Override
    public class_6880<class_1959> method_22387(int p_204159_, int p_204160_, int p_204161_) {
        return null;
    }

    @Override
    public boolean method_8608() {
        return true;
    }

    @Override
    public int method_8615() {
        return 0;
    }

    @Override
    public class_2874 method_8597() {
        return realWorld.method_8597();
    }

    @Override
    public int method_31607() {
        return realWorld.method_31607();
    }

    @Override
    public int method_22335(class_2338 blockPos, int amount) {
        return realWorld.method_22335(blockPos.method_10081(lookingAt), amount);
    }

    @Override
    public boolean method_8311(class_2338 blockPos) {
        return realWorld.method_8311(blockPos.method_10081(lookingAt));
    }

    @Override
    public long method_39224() {
        return 0;
    }

    @Override
    public class_6756<class_2248> method_8397() {
        return class_6754.method_39362();
    }

    @Override
    public class_6756<class_3611> method_8405() {
        return class_6754.method_39362();
    }

    @Override
    public class_5217 method_8401() {
        return this.realWorld.method_8401();
    }

    @Override
    public class_8921 method_54719() {
        return null;
    }

    @Override
    public class_1266 method_8404(class_2338 p_46800_) {
        return null;
    }

    @org.jetbrains.annotations.Nullable
    @Override
    public MinecraftServer method_8503() {
        return null;
    }

    @Override
    public class_2802 method_8398() {
        return null;
    }

    @Override
    public class_5819 method_8409() {
        return null;
    }

    @Override
    public void method_8396(@org.jetbrains.annotations.Nullable class_1657 p_46775_, class_2338 p_46776_, class_3414 p_46777_, class_3419 p_46778_, float p_46779_, float p_46780_) {

    }

    @Override
    public void method_8406(class_2394 p_46783_, double p_46784_, double p_46785_, double p_46786_, double p_46787_, double p_46788_, double p_46789_) {

    }

    @Override
    public void method_8444(@org.jetbrains.annotations.Nullable class_1657 p_46771_, int p_46772_, class_2338 p_46773_, int p_46774_) {

    }

    @Override
    public void method_32888(class_6880<class_5712> holder, class_243 vec3, class_5712.class_7397 context) {

    }

    @Override
    public float method_24852(class_2350 pDirection, boolean pShade) {
        class_638 clientLevel = (class_638) realWorld;
        boolean flag = clientLevel.method_28103().method_29993();
        if (!pShade) {
            return flag ? 0.9F : 1.0F;
        } else {
            switch (pDirection) {
                case field_11033:
                    return flag ? 0.9F : 0.5F;
                case field_11036:
                    return flag ? 0.9F : 1.0F;
                case field_11043:
                case field_11035:
                    return 0.8F;
                case field_11039:
                case field_11034:
                    return 0.6F;
                default:
                    return 1.0F;
            }
        }
    }

    @Override
    public class_3568 method_22336() {
        return class_310.method_1551().field_1687.method_22336();
    }

    @Override
    public class_2784 method_8621() {
        return null;
    }

    @Override
    public List<class_1297> method_8333(@org.jetbrains.annotations.Nullable class_1297 p_45936_, class_238 p_45937_, Predicate<? super class_1297> p_45938_) {
        return null;
    }

    @Override
    public <T extends class_1297> List<T> method_18023(class_5575<class_1297, T> p_151464_, class_238 p_151465_, Predicate<? super T> p_151466_) {
        return null;
    }

    @Override
    public List<? extends class_1657> method_18456() {
        return null;
    }

    @Override
    public boolean method_16358(class_2338 p_46938_, Predicate<class_2680> p_46939_) {
        return p_46939_.test(method_8320(p_46938_));
    }

    @Override
    public boolean method_35237(class_2338 p_151584_, Predicate<class_3610> p_151585_) {
        return false;
    }

    @Override
    public boolean method_8650(class_2338 p_46951_, boolean p_46952_) {
        return false;
    }

    @Override
    public boolean method_30093(class_2338 p_46957_, boolean p_46958_, @org.jetbrains.annotations.Nullable class_1297 p_46959_, int p_46960_) {
        return false;
    }

    @Override
    public int method_22339(class_2338 pos) {
        return 15;
    }

    @Override
    public void method_8413(class_2338 pos, class_2680 oldState, class_2680 newState, int flags) {
        realWorld.method_8413(pos, oldState, newState, flags);
    }

    @Override
    public void method_47967(class_1657 p_220363_, double p_220364_, double p_220365_, double p_220366_,
                                class_3414 p_220367_, class_3419 p_220368_, float p_220369_, float p_220370_, long p_220371_) {}

    @Override
    public void method_8465(class_1657 pPlayer, double pX, double pY, double pZ, class_6880<class_3414> pSound,
                                class_3419 pSource, float pVolume, float pPitch, long pSeed) {}

    @Override
    public void method_8449(class_1657 pPlayer, class_1297 pEntity, class_6880<class_3414> pSound, class_3419 pCategory,
                                float pVolume, float pPitch, long pSeed) {}

    @Override
    public void method_43128(@Nullable class_1657 player, double x, double y, double z, class_3414 soundIn,
                          class_3419 category, float volume, float pitch) {}

    @Override
    public void method_43129(@Nullable class_1657 p_217384_1_, class_1297 p_217384_2_, class_3414 p_217384_3_,
                          class_3419 p_217384_4_, float p_217384_5_, float p_217384_6_) {}

    @Override
    public class_1297 method_8469(int id) {
        return null;
    }

    @org.jetbrains.annotations.Nullable
    @Override
    public class_22 method_17891(class_9209 mapId) {
        return null;
    }

    @Override
    public boolean method_8649(class_1297 entityIn) {
        return realWorld.method_8649(entityIn);
    }

    @Override
    public void method_17890(class_9209 mapId, class_22 mapItemSavedData) {

    }

    @Override
    public class_9209 method_17889() {
        return realWorld.method_17889();
    }



    @Override
    public void method_8517(int breakerId, class_2338 pos, int progress) {}

    @Override
    public class_269 method_8428() {
        return realWorld.method_8428();
    }

    @Override
    public class_1863 method_8433() {
        return realWorld.method_8433();
    }

    @Override
    public void method_8455(class_2338 p_175666_1_, class_2248 p_175666_2_) {}

    @Override
    public void method_43275(@org.jetbrains.annotations.Nullable class_1297 pEntity, class_6880<class_5712> pGameEvent, class_243 pPos) {

    }

    @Override
    public String method_31419() {
        return realWorld.method_31419();
    }


    // Intentionally copied from LevelHeightAccessor. Workaround for issues caused
    // when other mods (such as Lithium)
    // override the vanilla implementations in ways which cause WrappedWorlds to
    // return incorrect, default height info.
    // WrappedWorld subclasses should implement their own getMinBuildHeight and
    // getHeight overrides where they deviate
    // from the defaults for their dimension.

    @Override
    public int method_31600() {
        return this.method_31607() + this.method_31605();
    }

    @Override
    public int method_32890() {
        return this.method_31597() - this.method_32891();
    }

    @Override
    public int method_32891() {
        return class_4076.method_18675(this.method_31607());
    }

    @Override
    public int method_31597() {
        return class_4076.method_18675(this.method_31600() - 1) + 1;
    }

    @Override
    public boolean method_31606(class_2338 pos) {
        return this.method_31601(pos.method_10264());
    }

    @Override
    public boolean method_31601(int y) {
        return y < this.method_31607() || y >= this.method_31600();
    }

    @Override
    public int method_31602(int y) {
        return this.method_31603(class_4076.method_18675(y));
    }

    @Override
    public int method_31603(int sectionY) {
        return sectionY - this.method_32891();
    }

    @Override
    public int method_31604(int sectionIndex) {
        return sectionIndex + this.method_32891();
    }

    // Invisible overrides for neoforge compatibility
    public void setDayTimeFraction(float dayTimePerTick) {

    }
    public void setDayTimePerTick(float dayTimePerTick) {

    }

    public float getDayTimePerTick(){
        return 0;
    }

    public float getDayTimeFraction(){
        return 0;
    }

}

==> nuggets-fabric-1.21.1-1.1.0.48-sources.jar: com/hollingsworth/nuggets/client/rendering/FakeRenderingWorld.java <==
package com.hollingsworth.nuggets.client.rendering;

import net.minecraft.class_1266;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1845;
import net.minecraft.class_1863;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_1959;
import net.minecraft.class_22;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_2350;
import net.minecraft.class_238;
import net.minecraft.class_2394;
import net.minecraft.class_243;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import net.minecraft.class_269;
import net.minecraft.class_2784;
import net.minecraft.class_2791;
import net.minecraft.class_2802;
import net.minecraft.class_2806;
import net.minecraft.class_2874;
import net.minecraft.class_2902;
import net.minecraft.class_310;
import net.minecraft.class_3414;
import net.minecraft.class_3419;
import net.minecraft.class_3568;
import net.minecraft.class_3610;
import net.minecraft.class_3611;
import net.minecraft.class_3612;
import net.minecraft.class_4076;
import net.minecraft.class_4543;
import net.minecraft.class_5217;
import net.minecraft.class_5269;
import net.minecraft.class_5455;
import net.minecraft.class_5575;
import net.minecraft.class_5577;
import net.minecraft.class_5712;
import net.minecraft.class_5819;
import net.minecraft.class_638;
import net.minecraft.class_6754;
import net.minecraft.class_6756;
import net.minecraft.class_6880;
import net.minecraft.class_7699;
import net.minecraft.class_8921;
import net.minecraft.class_9209;
import net.minecraft.core.*;
import net.minecraft.server.MinecraftServer;
import javax.annotation.Nullable;
import java.util.HashMap;
import java.util.List;
import java.util.function.Predicate;

public class FakeRenderingWorld extends class_1937 implements class_1936 {
    public final HashMap<class_2338, class_2680> positions = new HashMap<>();
    private class_1937 realWorld;
    private class_2338 lookingAt;

    public FakeRenderingWorld(class_1937 rWorld, List<StatePos> coordinates, class_2338 lookingAt) {
        this(rWorld);
        this.lookingAt = lookingAt;
        for (StatePos statePos : coordinates) {
            this.method_8652(statePos.pos, statePos.state, 0);
        }
        for (StatePos statePos : coordinates) {
            try {
                class_2680 adjustedState = class_2248.method_9510(statePos.state, this, statePos.pos);
                this.method_8652(statePos.pos, adjustedState, 0);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public FakeRenderingWorld(class_1937 world) {
        super((class_5269) world.method_8401(), world.method_27983(), world.method_30349(), world.method_40134(),
                world::method_16107, world.field_9236, world.method_27982(), 0, 0);
        this.realWorld = world;
    }

    @Nullable
    @Override
    public class_2586 method_8321(class_2338 pos) {
        class_2680 blockState = method_8320(pos);
        if (blockState.method_31709()) {
            class_2586 blockEntity = ((class_2343) blockState.method_26204()).method_10123(pos.method_10081(lookingAt), blockState);
            if(blockEntity == null){
                return null;
            }
            blockEntity.method_31662(this.realWorld);
            return blockEntity;
        }
        return null;
    }

    @Override
    public class_2680 method_8320(class_2338 pos) {
        return positions.containsKey(pos) ? positions.get(pos) : realWorld.method_8320(pos.method_10081(lookingAt));
    }

    public class_2680 getBlockStateWithoutReal(class_2338 pos) {
        return positions.containsKey(pos) ? positions.get(pos) : class_2246.field_10124.method_9564();
    }

    @Override
    public void method_39279(class_2338 p_186461_, class_2248 p_186462_, int p_186463_) {
        //noOp
    }

    @Override
    public boolean method_8652(class_2338 p_46944_, class_2680 p_46945_, int p_46946_) {
        return this.method_30092(p_46944_, p_46945_, p_46946_, 512);
    }

    @Override
    public boolean method_30092(class_2338 pos, class_2680 state, int p_46949_, int p_46950_) {
        positions.put(pos, state);
        return true;
    }

    @Override
    public class_3610 method_8316(class_2338 pos) {
        return class_3612.field_15906.method_15785();
    }

    @Override
    public int method_31605() {
        return realWorld.method_31605();
    }

    @Override
    public class_5455 method_30349() {
        return null;
    }

    @Override
    public class_1845 method_59547() {
        return null;
    }

    @Override
    public class_7699 method_45162() {
        return null;
    }

    @org.jetbrains.annotations.Nullable
    @Override
    public class_2791 method_8402(int pX, int pZ, class_2806 pChunkStatus, boolean pRequireChunk) {
        return null;
    }

    @Override
    public int method_8624(class_2902.class_2903 p_46827_, int p_46828_, int p_46829_) {
        return 0;
    }

    @Override
    public int method_8594() {
        return 0;
    }

    @Override
    public class_4543 method_22385() {
        return realWorld.method_22385();
    }

    @Override
    protected class_5577<class_1297> method_31592() {
        return null;
    }

    @Override
    public class_6880<class_1959> method_22387(int p_204159_, int p_204160_, int p_204161_) {
        return null;
    }

    @Override
    public boolean method_8608() {
        return true;
    }

    @Override
    public int method_8615() {
        return 0;
    }

    @Override
    public class_2874 method_8597() {
        return realWorld.method_8597();
    }

    @Override
    public int method_31607() {
        return realWorld.method_31607();
    }

    @Override
    public int method_22335(class_2338 blockPos, int amount) {
        return realWorld.method_22335(blockPos.method_10081(lookingAt), amount);
    }

    @Override
    public boolean method_8311(class_2338 blockPos) {
        return realWorld.method_8311(blockPos.method_10081(lookingAt));
    }

    @Override
    public long method_39224() {
        return 0;
    }

    @Override
    public class_6756<class_2248> method_8397() {
        return class_6754.method_39362();
    }

    @Override
    public class_6756<class_3611> method_8405() {
        return class_6754.method_39362();
    }

    @Override
    public class_5217 method_8401() {
        return this.realWorld.method_8401();
    }

    @Override
    public class_8921 method_54719() {
        return null;
    }

    @Override
    public class_1266 method_8404(class_2338 p_46800_) {
        return null;
    }

    @org.jetbrains.annotations.Nullable
    @Override
    public MinecraftServer method_8503() {
        return null;
    }

    @Override
    public class_2802 method_8398() {
        return null;
    }

    @Override
    public class_5819 method_8409() {
        return null;
    }

    @Override
    public void method_8396(@org.jetbrains.annotations.Nullable class_1657 p_46775_, class_2338 p_46776_, class_3414 p_46777_, class_3419 p_46778_, float p_46779_, float p_46780_) {

    }

    @Override
    public void method_8406(class_2394 p_46783_, double p_46784_, double p_46785_, double p_46786_, double p_46787_, double p_46788_, double p_46789_) {

    }

    @Override
    public void method_8444(@org.jetbrains.annotations.Nullable class_1657 p_46771_, int p_46772_, class_2338 p_46773_, int p_46774_) {

    }

    @Override
    public void method_32888(class_6880<class_5712> holder, class_243 vec3, class_5712.class_7397 context) {

    }

    @Override
    public float method_24852(class_2350 pDirection, boolean pShade) {
        class_638 clientLevel = (class_638) realWorld;
        boolean flag = clientLevel.method_28103().method_29993();
        if (!pShade) {
            return flag ? 0.9F : 1.0F;
        } else {
            switch (pDirection) {
                case field_11033:
                    return flag ? 0.9F : 0.5F;
                case field_11036:
                    return flag ? 0.9F : 1.0F;
                case field_11043:
                case field_11035:
                    return 0.8F;
                case field_11039:
                case field_11034:
                    return 0.6F;
                default:
                    return 1.0F;
            }
        }
    }

    @Override
    public class_3568 method_22336() {
        return class_310.method_1551().field_1687.method_22336();
    }

    @Override
    public class_2784 method_8621() {
        return null;
    }

    @Override
    public List<class_1297> method_8333(@org.jetbrains.annotations.Nullable class_1297 p_45936_, class_238 p_45937_, Predicate<? super class_1297> p_45938_) {
        return null;
    }

    @Override
    public <T extends class_1297> List<T> method_18023(class_5575<class_1297, T> p_151464_, class_238 p_151465_, Predicate<? super T> p_151466_) {
        return null;
    }

    @Override
    public List<? extends class_1657> method_18456() {
        return null;
    }

    @Override
    public boolean method_16358(class_2338 p_46938_, Predicate<class_2680> p_46939_) {
        return p_46939_.test(method_8320(p_46938_));
    }

    @Override
    public boolean method_35237(class_2338 p_151584_, Predicate<class_3610> p_151585_) {
        return false;
    }

    @Override
    public boolean method_8650(class_2338 p_46951_, boolean p_46952_) {
        return false;
    }

    @Override
    public boolean method_30093(class_2338 p_46957_, boolean p_46958_, @org.jetbrains.annotations.Nullable class_1297 p_46959_, int p_46960_) {
        return false;
    }

    @Override
    public int method_22339(class_2338 pos) {
        return 15;
    }

    @Override
    public void method_8413(class_2338 pos, class_2680 oldState, class_2680 newState, int flags) {
        realWorld.method_8413(pos, oldState, newState, flags);
    }

    @Override
    public void method_47967(class_1657 p_220363_, double p_220364_, double p_220365_, double p_220366_,
                                class_3414 p_220367_, class_3419 p_220368_, float p_220369_, float p_220370_, long p_220371_) {}

    @Override
    public void method_8465(class_1657 pPlayer, double pX, double pY, double pZ, class_6880<class_3414> pSound,
                                class_3419 pSource, float pVolume, float pPitch, long pSeed) {}

    @Override
    public void method_8449(class_1657 pPlayer, class_1297 pEntity, class_6880<class_3414> pSound, class_3419 pCategory,
                                float pVolume, float pPitch, long pSeed) {}

    @Override
    public void method_43128(@Nullable class_1657 player, double x, double y, double z, class_3414 soundIn,
                          class_3419 category, float volume, float pitch) {}

    @Override
    public void method_43129(@Nullable class_1657 p_217384_1_, class_1297 p_217384_2_, class_3414 p_217384_3_,
                          class_3419 p_217384_4_, float p_217384_5_, float p_217384_6_) {}

    @Override
    public class_1297 method_8469(int id) {
        return null;
    }

    @org.jetbrains.annotations.Nullable
    @Override
    public class_22 method_17891(class_9209 mapId) {
        return null;
    }

    @Override
    public boolean method_8649(class_1297 entityIn) {
        return realWorld.method_8649(entityIn);
    }

    @Override
    public void method_17890(class_9209 mapId, class_22 mapItemSavedData) {

    }

    @Override
    public class_9209 method_17889() {
        return realWorld.method_17889();
    }



    @Override
    public void method_8517(int breakerId, class_2338 pos, int progress) {}

    @Override
    public class_269 method_8428() {
        return realWorld.method_8428();
    }

    @Override
    public class_1863 method_8433() {
        return realWorld.method_8433();
    }

    @Override
    public void method_8455(class_2338 p_175666_1_, class_2248 p_175666_2_) {}

    @Override
    public void method_43275(@org.jetbrains.annotations.Nullable class_1297 pEntity, class_6880<class_5712> pGameEvent, class_243 pPos) {

    }

    @Override
    public String method_31419() {
        return realWorld.method_31419();
    }


    // Intentionally copied from LevelHeightAccessor. Workaround for issues caused
    // when other mods (such as Lithium)
    // override the vanilla implementations in ways which cause WrappedWorlds to
    // return incorrect, default height info.
    // WrappedWorld subclasses should implement their own getMinBuildHeight and
    // getHeight overrides where they deviate
    // from the defaults for their dimension.

    @Override
    public int method_31600() {
        return this.method_31607() + this.method_31605();
    }

    @Override
    public int method_32890() {
        return this.method_31597() - this.method_32891();
    }

    @Override
    public int method_32891() {
        return class_4076.method_18675(this.method_31607());
    }

    @Override
    public int method_31597() {
        return class_4076.method_18675(this.method_31600() - 1) + 1;
    }

    @Override
    public boolean method_31606(class_2338 pos) {
        return this.method_31601(pos.method_10264());
    }

    @Override
    public boolean method_31601(int y) {
        return y < this.method_31607() || y >= this.method_31600();
    }

    @Override
    public int method_31602(int y) {
        return this.method_31603(class_4076.method_18675(y));
    }

    @Override
    public int method_31603(int sectionY) {
        return sectionY - this.method_32891();
    }

    @Override
    public int method_31604(int sectionIndex) {
        return sectionIndex + this.method_32891();
    }

    // Invisible overrides for neoforge compatibility
    public void setDayTimeFraction(float dayTimePerTick) {

    }
    public void setDayTimePerTick(float dayTimePerTick) {

    }

    public float getDayTimePerTick(){
        return 0;
    }

    public float getDayTimeFraction(){
        return 0;
    }

}
